@@ -1,7 +1,7 @@
 /*
- * $Header: /home/cvs/jakarta-commons/validator/src/share/org/apache/commons/validator/Field.java,v 1.31.2.3 2004/11/11 15:32:03 niallp Exp $
- * $Revision: 1.31.2.3 $
- * $Date: 2004/11/11 15:32:03 $
+ * $Header: /home/cvs/jakarta-commons/validator/src/share/org/apache/commons/validator/Field.java,v 1.31.2.1 2004/06/22 02:24:38 husted Exp $
+ * $Revision: 1.31.2.1 $
+ * $Date: 2004/06/22 02:24:38 $
  *
  * ====================================================================
  * Copyright 2001-2004 The Apache Software Foundation
@@ -239,32 +239,14 @@ public class Field implements Cloneable, Serializable {
      * Add a <code>Msg</code> to the <code>Field</code>.
      */
     public void addMsg(Msg msg) {
-        hMsgs.put(msg.getName(), msg);
+        hMsgs.put(msg.getName(), msg.getKey());
     }
 
     /**
      * Retrieve a message value.
      */
     public String getMsg(String key) {
-        Msg msg = getMessage(key);
-        return (msg == null) ? null : msg.getKey();
-    }
-
-    /**
-     * Retrieve a message object.
-     * @since Validator 1.1.4
-     */
-    public Msg getMessage(String key) {
-        return (Msg)hMsgs.get(key);
-    }
-
-    /**
-     * The <code>Field</code>'s messages are returned as an
-     * unmodifiable <code>Map</code>.
-     * @since Validator 1.1.4
-     */
-    public Map getMessages() {
-        return Collections.unmodifiableMap(hMsgs);
+        return (String) hMsgs.get(key);
     }
 
     /**
@@ -645,9 +627,11 @@ public class Field implements Cloneable, Serializable {
         String varKey = TOKEN_START + TOKEN_VAR;
         // Process Messages
         if (key != null && !key.startsWith(varKey)) {
-            for (Iterator i = hMsgs.values().iterator(); i.hasNext();) {
-                Msg msg = (Msg) i.next();
-                msg.setKey(ValidatorUtils.replace(msg.getKey(), key, replaceValue));
+            for (Iterator i = hMsgs.keySet().iterator(); i.hasNext();) {
+                String msgKey = (String) i.next();
+                String value = this.getMsg(msgKey);
+
+                hMsgs.put(msgKey, ValidatorUtils.replace(value, key, replaceValue));
             }
         }
 
